"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.payment_api import PaymentApi  # noqa: E501


class TestPaymentApi(unittest.TestCase):
    """PaymentApi unit test stubs"""

    def setUp(self):
        self.api = PaymentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_close_payment(self):
        """Test case for close_payment

        ClosePayment  # noqa: E501
        """
        pass

    def test_create_payment(self):
        """Test case for create_payment

        CreatePayment  # noqa: E501
        """
        pass

    def test_invoke_payment(self):
        """Test case for invoke_payment

        InvokePayment  # noqa: E501
        """
        pass

    def test_query_payment(self):
        """Test case for query_payment

        QueryPayment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
