"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.customs_api import CustomsApi  # noqa: E501


class TestCustomsApi(unittest.TestCase):
    """CustomsApi unit test stubs"""

    def setUp(self):
        self.api = CustomsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customs_payment(self):
        """Test case for get_customs_payment

        GetCustomsPayment  # noqa: E501
        """
        pass

    def test_post_customs_identification(self):
        """Test case for post_customs_identification

        PostCustomsIdentification  # noqa: E501
        """
        pass

    def test_post_customs_payment(self):
        """Test case for post_customs_payment

        PostCustomsPayment  # noqa: E501
        """
        pass

    def test_put_customs_payment(self):
        """Test case for put_customs_payment

        PutCustomsPayment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
