"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nomad_broker_cli
from nomad_broker_cli.model.customs_code import CustomsCode
from nomad_broker_cli.model.payment_method import PaymentMethod
globals()['CustomsCode'] = CustomsCode
globals()['PaymentMethod'] = PaymentMethod
from nomad_broker_cli.model.customs_payment_request import CustomsPaymentRequest


class TestCustomsPaymentRequest(unittest.TestCase):
    """CustomsPaymentRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCustomsPaymentRequest(self):
        """Test CustomsPaymentRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CustomsPaymentRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
