"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.payout_api import PayoutApi  # noqa: E501


class TestPayoutApi(unittest.TestCase):
    """PayoutApi unit test stubs"""

    def setUp(self):
        self.api = PayoutApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_abroad_payout(self):
        """Test case for get_abroad_payout

        GetAbroadPayout  # noqa: E501
        """
        pass

    def test_get_abroad_payout_bill(self):
        """Test case for get_abroad_payout_bill

        GetAbroadPayoutBill  # noqa: E501
        """
        pass

    def test_post_abroad_payout(self):
        """Test case for post_abroad_payout

        PostAbroadPayout  # noqa: E501
        """
        pass

    def test_post_abroad_payout_bill(self):
        """Test case for post_abroad_payout_bill

        PostAbroadPayoutBill  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
