"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.profit_api import ProfitApi  # noqa: E501


class TestProfitApi(unittest.TestCase):
    """ProfitApi unit test stubs"""

    def setUp(self):
        self.api = ProfitApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_profit_receiver(self):
        """Test case for delete_profit_receiver

        DeleteProfitReceiver  # noqa: E501
        """
        pass

    def test_get_profit_sharing(self):
        """Test case for get_profit_sharing

        GetProfitSharing  # noqa: E501
        """
        pass

    def test_post_profit_receiver(self):
        """Test case for post_profit_receiver

        PostProfitReceiver  # noqa: E501
        """
        pass

    def test_post_profit_sharing(self):
        """Test case for post_profit_sharing

        PostProfitSharing  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
