"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.refund_api import RefundApi  # noqa: E501


class TestRefundApi(unittest.TestCase):
    """RefundApi unit test stubs"""

    def setUp(self):
        self.api = RefundApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_refund(self):
        """Test case for create_refund

        CreateRefund  # noqa: E501
        """
        pass

    def test_query_refund(self):
        """Test case for query_refund

        QueryRefund  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
