"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "nomad_broker_cli"
VERSION = "1.5.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
  "nulltype",
]

setup(
    name=NAME,
    version=VERSION,
    description="Nomad Broker",
    author="OpenAPI Generator community",
    author_email="ben.song@samarkand.global",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Nomad Broker"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,

    long_description_content_type='text/markdown',
    long_description=open('README.md', encoding='utf-8').read(),
)
